jk_fileaccess
=============

Introduction
------------

This python module provides a uniform interface to process files that are either stored locally or remotely.

**What this uniform interface is:** A simple way to iterate over a (very) large set of files. This should
be fast, this should be simple. That is the goal this module tries to achieve.

**What this uniform interface not is:** A full featured file system API. The classes are quite limited.
(Nevertheless feel free to aid in development of this module to extend the functionality of these classes.)

Information about this module can be found here:

* [github.org](https://github.com/jkpubsrc/python-module-jk-fileaccess)
* [pypi.python.org](https://pypi.python.org/pypi?name=jk_temporary)

Contact Information
-------------------

This is Open Source code. That not only gives you the possibility of freely using this code it also
allows you to contribute. Feel free to contact the author(s) of this software listed below, either
for comments, collaboration requests, suggestions for improvement or reporting bugs:

* Jürgen Knauth: jknauth@uni-goettingen.de, pubsrc@binary-overflow.de

License
-------

This software is provided under the following license:

* Apache Software License 2.0



